==> sgwi-0.7.tbz: www/sgwi/awl.php <==
<?
	require "config.inc.php";
	require "db.inc.php";
	require "tools.inc.php";

	$mode = $_GET["mode"];
	$csort = $_GET["csort"];
	$sort = $_GET["sort"];

	if ($sort==null || $sort=="") {
	  if ($mode == "email")
	    $sort = "sender_name";
	  else
	    $sort = "sender_domain";
	}
	$dir = "asc";
	$ndir = "desc";
	if ($sort == $csort && $_GET["order"] == "desc")
	{
		$dir = "desc";
		$ndir = "asc";
	}
?>
<HTML>
<HEAD>
<TITLE>Whitelisted <? if ($mode=="email") print "e-mail addresses"; else print "domains"; ?></TITLE>
<BODY>
<TABLE WIDTH=100% HEIGHT=100%><TR VALIGN=CENTER><TD ALIGN=CENTER>

<H1>Whitelisted <? if ($mode=="email") print "e-mail addresses"; else print "domains"; ?></H1>

<?
# mysql> describe from_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_name   | varchar(64)   |      | PRI |                |       |
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 5 rows in set (0.00 sec)

# mysql> describe domain_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 4 rows in set (0.00 sec)
?>

<TABLE>
<TR>
<? if ($mode=="email") print "<TD><B><A HREF=\"awl.php?mode=".$mode."&sort=sender_name&csort=".$sort."&order=".$ndir."\">Sender name</A></B></TD>"; ?>
<TD><B><A HREF="awl.php?mode=<? print $mode; ?>&sort=sender_domain&csort=<? print $sort; ?>&order=<? print $ndir; ?>">Sender domain</A></B></TD>
<TD><B><A HREF="awl.php?mode=<? print $mode; ?>&sort=src&csort=<? print $sort; ?>&order=<? print $ndir; ?>">Source</A></B></TD>
<TD><B><A HREF="awl.php?mode=<? print $mode; ?>&sort=first_seen&csort=<? print $sort; ?>&order=<? print $ndir; ?>">First seen</A></B></TD>
<TD><B><A HREF="awl.php?mode=<? print $mode; ?>&sort=last_seen&csort=<? print $sort; ?>&order=<? print $ndir; ?>">Last seen</A></B></TD>
<TD></TD>
</TR>

<?
	if ($mode=="email")
	{
		if ($sort == "sender_name")
		  $order = "sender_name ".$dir.", sender_domain ".$dir;
		else if ($sort == "sender_domain")
		  $order = "sender_domain ".$dir.", sender_name ".$dir;
		else 
		  $order = $sort." ".$dir;
		$query = "SELECT sender_name, sender_domain, src, first_seen, last_seen FROM from_awl ORDER BY ".$order;
	}
	else
	{
		$order = $sort." ".$dir;
		$query = "SELECT sender_domain, src, first_seen, last_seen FROM domain_awl ORDER BY ".$order;
	}


	$result = do_query($query);
	while($line = fetch_row($result))
	{
		?><TR><?
		if ($mode=="email") print "<TD>".$line["sender_name"]."</TD>";
		?><TD><? print $line["sender_domain"]; ?></TD><?
		?><TD><? print $line["src"]; ?></TD><?
		?><TD><? print $line["first_seen"]; ?></TD><?
		?><TD><? print $line["last_seen"]; ?></TD><?
		?><TD><A HREF="awl_delete.php?mode=<?
			if ($mode=="email")
				print "email&sender_name=".enchttp($line["sender_name"]);
			else
				print "domains";
			?>&sender_domain=<? print enchttp($line["sender_domain"]);
			?>&src=<? print $line["src"]; ?>">Delete</A></TD><?
		?></TR><?
		print "\n";
	}
?>
</TABLE>
<A HREF="awl_delete_undef.php?mode=<? print $_GET["mode"]; ?>">Delete '-undef-' entries</A><BR>
<BR>
<H2>Add to whitelist</H2>
<FORM ACTION="awl_add.php?mode=<? print $_GET["mode"]; ?>" METHOD="POST">
<TABLE>
<? if ($mode == "email") { ?>
<TR><TD>Sender name:</TD><TD><INPUT TYPE="TEXT" NAME="sender_name" SIZE=64 WIDTH=64></TD></TR>
<? } ?>
<TR><TD>Sender domain:</TD><TD><INPUT TYPE="TEXT" NAME="sender_domain" SIZE=64 WIDTH=255></TD></TR>
<TR><TD>Source (class c or d):</TD><TD><INPUT TYPE="TEXT" NAME="src" SIZE=15 WIDTH=15></TD></TR>
<TR><TD></TD><TD><INPUT TYPE="SUBMIT" VALUE="Add"></TD></TR>
</TABLE>
</FORM>
<BR>
<BR>

<A HREF="index.php">Main menu</A><BR>

<BR>
<BR>

</TD></TR>

<? require "copyright.inc.php" ?>

</TABLE>
</BODY>
</HTML>

==> sgwi-0.8.tbz: www/sgwi/awl.php <==
<?php
	require "config.inc.php";
	require "db.inc.php";
	require "tools.inc.php";

	$mode = $_GET["mode"];
	$csort = $_GET["csort"];
	$sort = $_GET["sort"];

	if ($sort==null || $sort=="") {
	  if ($mode == "email")
	    $sort = "sender_name";
	  else
	    $sort = "sender_domain";
	}
	$dir = "asc";
	$ndir = "desc";
	if ($sort == $csort && $_GET["order"] == "desc")
	{
		$dir = "desc";
		$ndir = "asc";
	}
?>
<HTML>
<HEAD>
<TITLE>Whitelisted <?php if ($mode=="email") print "e-mail addresses"; else print "domains"; ?></TITLE>
<BODY>
<TABLE WIDTH=100% HEIGHT=100%><TR VALIGN=CENTER><TD ALIGN=CENTER>

<H1>Whitelisted <?php if ($mode=="email") print "e-mail addresses"; else print "domains"; ?></H1>

<?php
# mysql> describe from_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_name   | varchar(64)   |      | PRI |                |       |
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 5 rows in set (0.00 sec)

# mysql> describe domain_awl;
# +---------------+---------------+------+-----+----------------+-------+
# | Field         | Type          | Null | Key | Default        | Extra |
# +---------------+---------------+------+-----+----------------+-------+
# | sender_domain | varchar(255)  |      | PRI |                |       |
# | src           | varchar(39)   |      | PRI |                |       |
# | first_seen    | timestamp(14) | YES  |     | NULL           |       |
# | last_seen     | timestamp(14) | YES  | MUL | 00000000000000 |       |
# +---------------+---------------+------+-----+----------------+-------+
# 4 rows in set (0.00 sec)
?>

<TABLE>
<TR>
<?php if ($mode=="email") print "<TD><B><A HREF=\"awl.php?mode=".$mode."&sort=sender_name&csort=".$sort."&order=".$ndir."\">Sender name</A></B></TD>"; ?>
<TD><B><A HREF="awl.php?mode=<?php print $mode; ?>&sort=sender_domain&csort=<?php print $sort; ?>&order=<?php print $ndir; ?>">Sender domain</A></B></TD>
<TD><B><A HREF="awl.php?mode=<?php print $mode; ?>&sort=src&csort=<?php print $sort; ?>&order=<?php print $ndir; ?>">Source</A></B></TD>
<TD><B><A HREF="awl.php?mode=<?php print $mode; ?>&sort=first_seen&csort=<?php print $sort; ?>&order=<?php print $ndir; ?>">First seen</A></B></TD>
<TD><B><A HREF="awl.php?mode=<?php print $mode; ?>&sort=last_seen&csort=<?php print $sort; ?>&order=<?php print $ndir; ?>">Last seen</A></B></TD>
<TD></TD>
</TR>

<?php
	if ($mode=="email")
	{
		if ($sort == "sender_name")
		  $order = "sender_name ".$dir.", sender_domain ".$dir;
		else if ($sort == "sender_domain")
		  $order = "sender_domain ".$dir.", sender_name ".$dir;
		else 
		  $order = $sort." ".$dir;
		$query = "SELECT sender_name, sender_domain, src, first_seen, last_seen FROM from_awl ORDER BY ".$order;
	}
	else
	{
		$order = $sort." ".$dir;
		$query = "SELECT sender_domain, src, first_seen, last_seen FROM domain_awl ORDER BY ".$order;
	}


	$result = do_query($query);
	while($line = fetch_row($result))
	{
		?><TR><?php
		if ($mode=="email") print "<TD>".$line["sender_name"]."</TD>";
		?><TD><?php print $line["sender_domain"]; ?></TD><?php
		?><TD><?php print $line["src"]; ?></TD><?php
		?><TD><?php print $line["first_seen"]; ?></TD><?php
		?><TD><?php print $line["last_seen"]; ?></TD><?php
		?><TD><A HREF="awl_delete.php?mode=<?php
			if ($mode=="email")
				print "email&sender_name=".enchttp($line["sender_name"]);
			else
				print "domains";
			?>&sender_domain=<?php print enchttp($line["sender_domain"]);
			?>&src=<?php print $line["src"]; ?>">Delete</A></TD><?php
		?></TR><?php
		print "\n";
	}
?>
</TABLE>
<A HREF="awl_delete_undef.php?mode=<?php print $_GET["mode"]; ?>">Delete '-undef-' entries</A><BR>
<BR>
<H2>Add to whitelist</H2>
<FORM ACTION="awl_add.php?mode=<?php print $_GET["mode"]; ?>" METHOD="POST">
<TABLE>
<?php if ($mode == "email") { ?>
<TR><TD>Sender name:</TD><TD><INPUT TYPE="TEXT" NAME="sender_name" SIZE=64 WIDTH=64></TD></TR>
<?php } ?>
<TR><TD>Sender domain:</TD><TD><INPUT TYPE="TEXT" NAME="sender_domain" SIZE=64 WIDTH=255></TD></TR>
<TR><TD>Source (class c or d):</TD><TD><INPUT TYPE="TEXT" NAME="src" SIZE=15 WIDTH=15></TD></TR>
<TR><TD></TD><TD><INPUT TYPE="SUBMIT" VALUE="Add"></TD></TR>
</TABLE>
</FORM>
<BR>
<BR>

<A HREF="index.php">Main menu</A><BR>

<BR>
<BR>

</TD></TR>

<?php require "copyright.inc.php" ?>

</TABLE>
</BODY>
</HTML>
